@@ -1,9 +1,10 @@
 """Certbot client interfaces."""
 import abc
+
 import six
 import zope.interface
 
-# pylint: disable=no-self-argument,no-method-argument,no-init,inherit-non-class
+# pylint: disable=no-self-argument,no-method-argument,inherit-non-class
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -253,6 +254,12 @@ class IConfig(zope.interface.Interface):
         "If updates provided by installer enhancements when Certbot is being run"
         " with \"renew\" verb should be disabled.")
 
+    preferred_chain = zope.interface.Attribute(
+        "If the CA offers multiple certificate chains, prefer the chain with "
+        "an issuer matching this Subject Common Name. If no match, the default "
+        "offered chain will be used."
+    )
+
 class IInstaller(IPlugin):
     """Generic Certbot Installer Interface.
 
